BehaviorTree

Struct BehaviorTree 

pub struct BehaviorTree { /* private fields */ }
A behavior tree that can be executed with a context

Implementations

Source

impl BehaviorTree

pub fn from_mdsl(mdsl: &str) -> Result<Self>

Create a new behavior tree from an MDSL string

pub fn from_node(root: Node) -> Self

Create a behavior tree from a pre-built node

pub fn tick(&mut self, context: &TreeContext) -> Result<NodeResult>

Execute one tick of the behavior tree

pub fn tick_with_delta( &mut self, context: &TreeContext, delta_time: f64, ) -> Result<NodeResult>

Execute one tick of the behavior tree with delta time

pub fn reset(&mut self)

Reset the tree to its initial state

pub fn get_state(&self) -> NodeState

Get the current state of the tree

pub fn is_running(&self) -> bool

Check if the tree is currently running